glymur: a Python interface for JPEG 2000
=========================================

**glymur** contains a Python interface to the OpenJPEG library which
allows one to read and write JPEG 2000 files.  **glymur** works on
Python 2.6, 2.7 and 3.3.  Python 3.3 is strongly
recommended.

Please read the docs, https://glymur.readthedocs.org/en/latest/
